@@ -1,4 +1,6 @@
-#!/usr/bin/env python
+# coding: utf-8
+
+from __future__ import unicode_literals, division
 
 """
 This module implements the main Custodian class, which manages a list of jobs
@@ -6,7 +8,6 @@ given a set of error handlers, the abstract base classes for the
 ErrorHandlers and Jobs.
 """
 
-from __future__ import division
 import six
 from six.moves import filter
 
